# y2

Why have two when one will do?

<p>
<a href="https://pypi.org/project/y2"><img alt="PyPI" src="https://img.shields.io/pypi/v/y2"></a>
<a href="https://pypi.org/project/y2"><img alt="Python veresions supported" src="https://img.shields.io/pypi/pyversions/y2"></a>
<a href="https://github.com/mangoumbrella/y2/blob/main/LICENSE"><img alt="License" src="https://img.shields.io/pypi/l/y2.svg"></a>
</p>

## Changelog

See [CHANGELOG.md](CHANGELOG.md).

## License

[y2](https://github.com/mangoumbrella/y2) is licensed under the terms of the Apache license. See [LICENSE](LICENSE) for more information.
